@@ -6,7 +6,7 @@
 General Functions
 """
 #
-#  Copyright 2018-2019 Dominic Davis-Foster <dominic@davis-foster.co.uk>
+#  Copyright © 2018-2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU Lesser General Public License as published by
@@ -100,16 +100,16 @@ def check_dependencies(dependencies, prt=True):
 	
 	missing_modules = []
 	for requirement in dependencies:
-		if not requirement in modules:
+		if requirement not in modules:
 			missing_modules.append(requirement)
 	
 	if prt:
 		if len(missing_modules) == 0:
 			print("All modules installed")
 		else:
-			print("""\rThe following modules are missing.
-	Please check the documentation.""")
+			print("The following modules are missing.")
 			print(missing_modules)
+			print("Please check the documentation.")
 		print("")
 	
 	else:
@@ -148,7 +148,7 @@ def list2str(the_list, sep=","):
 	return sep.join([str(x) for x in the_list])
 
 
-def splitLen(string,n):
+def split_len(string, n):
 	"""
 	Split a string every x characters
 	
@@ -158,12 +158,16 @@ def splitLen(string,n):
 	:return:
 	"""
 	
-	return [string[i:i+n] for i in range(0,len(string),n)]
+	return [string[i:i + n] for i in range(0, len(string), n)]
+
+
+splitLen = split_len
 
 
 def permutations(data, n=2):
 	"""
-	Return permutations containing `n` items from `data` without any reverse duplicates
+	Return permutations containing `n` items from `data` without any reverse duplicates.
+	If ``n`` is equal to or greater than the length of the data an empty list of returned
 	
 	:type data: list or string
 	:type n: int
@@ -172,6 +176,10 @@ def permutations(data, n=2):
 	"""
 	
 	import itertools
+	
+	if n == 0:
+		raise ValueError("`n` cannot be 0")
+	
 	perms = []
 	for i in itertools.permutations(data, n):
 		"""from https://stackoverflow.com/questions/10201977/how-to-reverse-tuples-in-python"""
@@ -216,7 +224,7 @@ class bdict(dict):
 		if len(args) == 0:
 			for key, value in kwargs.items():
 				self.__setitem__(key, value)
-
+	
 	def __setitem__(self, key, val):
 		if key in self or val in self:
 			if key in self and self[key] != val:
@@ -259,7 +267,7 @@ class bdict(dict):
 				key = "_False"
 		
 		val = dict.__getitem__(self, key)
-
+		
 		if val == "_None":
 			return None
 		elif val == "_True":
